@@ -1,7 +1,6 @@
 from lightning.app.runners.cloud import CloudRuntime
 from lightning.app.runners.multiprocess import MultiProcessRuntime
 from lightning.app.runners.runtime import dispatch, Runtime
-from lightning.app.runners.singleprocess import SingleProcessRuntime
 from lightning.app.utilities.app_commands import run_app_commands
 from lightning.app.utilities.load_app import load_app_from_file
 
@@ -11,6 +10,5 @@ __all__ = [
     "run_app_commands",
     "Runtime",
     "MultiProcessRuntime",
-    "SingleProcessRuntime",
     "CloudRuntime",
 ]
