@@ -6,6 +6,7 @@ from lightning.app.core.queues import QueuingSystem
 from lightning.app.runners.backends.backend import Backend, WorkManager
 from lightning.app.utilities.enum import WorkStageStatus
 from lightning.app.utilities.network import _check_service_url_is_ready
+from lightning.app.utilities.port import disable_port, enable_port
 from lightning.app.utilities.proxies import ProxyWorkRun, WorkRunner
 
 
@@ -30,7 +31,10 @@ class MultiProcessWorkManager(WorkManager):
             flow_to_work_delta_queue=self.app.flow_to_work_delta_queues[self.work.name],
             run_executor_cls=self.work._run_executor_cls,
         )
-        self._process = multiprocessing.Process(target=self._work_runner)
+
+        start_method = self.work._start_method
+        context = multiprocessing.get_context(start_method)
+        self._process = context.Process(target=self._work_runner)
         self._process.start()
 
     def kill(self):
@@ -83,3 +87,24 @@ class MultiProcessingBackend(Backend):
     def stop_work(self, app, work: "lightning.app.LightningWork") -> None:
         work_manager: MultiProcessWorkManager = app.processes[work.name]
         work_manager.kill()
+
+
+class CloudMultiProcessingBackend(MultiProcessingBackend):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        # Note: Track the open ports to close them on termination.
+        self.ports = []
+
+    def create_work(self, app, work) -> None:
+        work._host = "0.0.0.0"
+        nc = enable_port()
+        self.ports.append(nc.port)
+        work._port = nc.port
+        work._future_url = f"https://{nc.host}"
+        return super().create_work(app, work)
+
+    def stop_work(self, app, work: "lightning.app.LightningWork") -> None:
+        disable_port(work._port)
+        self.ports = [port for port in self.ports if port != work._port]
+        return super().stop_work(app, work)
