@@ -574,7 +574,10 @@ class ModelCheckpoint(Checkpoint):
             return self.dirpath
 
         if len(trainer.loggers) > 0:
-            save_dir = trainer.loggers[0].save_dir or trainer.default_root_dir
+            if trainer.loggers[0].save_dir is not None:
+                save_dir = trainer.loggers[0].save_dir
+            else:
+                save_dir = trainer.default_root_dir
             name = trainer.loggers[0].name
             version = trainer.loggers[0].version
             version = version if isinstance(version, str) else f"version_{version}"
@@ -637,7 +640,7 @@ class ModelCheckpoint(Checkpoint):
         previous, self.last_model_path = self.last_model_path, filepath
         self._save_checkpoint(trainer, filepath)
         if previous and previous != filepath:
-            trainer.strategy.remove_checkpoint(previous)
+            self._remove_checkpoint(trainer, previous)
 
     def _save_monitor_checkpoint(self, trainer: "pl.Trainer", monitor_candidates: Dict[str, Tensor]) -> None:
         assert self.monitor
@@ -656,7 +659,7 @@ class ModelCheckpoint(Checkpoint):
         previous, self.best_model_path = self.best_model_path, filepath
         self._save_checkpoint(trainer, filepath)
         if self.save_top_k == 1 and previous and previous != filepath:
-            trainer.strategy.remove_checkpoint(previous)
+            self._remove_checkpoint(trainer, previous)
 
     def _update_best_and_save(
         self, current: Tensor, trainer: "pl.Trainer", monitor_candidates: Dict[str, Tensor]
@@ -698,7 +701,7 @@ class ModelCheckpoint(Checkpoint):
         self._save_checkpoint(trainer, filepath)
 
         if del_filepath is not None and filepath != del_filepath:
-            trainer.strategy.remove_checkpoint(del_filepath)
+            self._remove_checkpoint(trainer, del_filepath)
 
     def to_yaml(self, filepath: Optional[_PATH] = None) -> None:
         """Saves the `best_k_models` dict containing the checkpoint paths with the corresponding scores to a YAML
@@ -715,3 +718,7 @@ class ModelCheckpoint(Checkpoint):
         state to diverge between ranks."""
         exists = self._fs.exists(filepath)
         return trainer.strategy.broadcast(exists)
+
+    def _remove_checkpoint(self, trainer: "pl.Trainer", filepath: str) -> None:
+        """Calls the strategy to remove the checkpoint file."""
+        trainer.strategy.remove_checkpoint(filepath)
